@@ -3,6 +3,6 @@
 #########################################################
 
 python.method.call <- function( py.object, py.method, ... ){
-    python.call( paste( py.object, py.method, sep = "." ) )
+    python.call(paste(py.object, py.method, sep = "."), ... )
 }
 
